@@ -5,17 +5,32 @@
 This module implements the naming check.
 """
 
-from re import fullmatch
-from pathlib import Path
 from fnmatch import fnmatch
+from pathlib import Path
+from re import fullmatch
 
-from treecker.core.configuration import config
+from treecker import config
+from treecker.core.colors import colorize
 
-def issues(tree: dict, path: list = []) -> list:
-    """Return a list of the naming issues."""
+def issues(tree, path=[]):
+    """Return a list of the naming issues.
+
+    Parameters
+    ----------
+    tree : dict
+        Directory node.
+    path : list
+        Initial path.
+
+    Returns
+    -------
+    list
+        Issues.
+
+    """
     listing = []
-    pattern = config.get(__name__, 'match')
-    ignore = config.get(__name__, 'ignore').split()
+    pattern = config.get(__name__, 'match-pattern')
+    ignore = config.get(__name__, 'ignore-patterns').split()
     if isinstance(tree, dict):
         for name, child in tree.items():
             if fullmatch(pattern, name) is None:
@@ -25,15 +40,26 @@ def issues(tree: dict, path: list = []) -> list:
             listing += issues(child, path+[name])
     return listing
 
-def issues_log(issues: list) -> str:
-    """Return a printable log of the naming issues."""
+def issues_log(issues):
+    """Return a printable log of the naming issues.
+
+    Parameters
+    ----------
+    issues : list
+        Issues.
+
+    Returns
+    -------
+    str
+        Issues log.
+
+    """
     lines = []
     color = config.get(__name__, 'color-issue')
-    color = eval(f"'{color}'")
     for issue in issues:
         path = Path(*issue['path'])
         text = issue['text']
-        line = f'{path} {color}{text}\033[0m'
+        line = f'{path} {colorize(text, color)}'
         lines.append(line)
     if len(issues) == 0:
         lines.append("no issue found")
